﻿// 在 ASP.NET MVC 中创建自定义 HtmlHelper 示例代码
// http://snowdream.cnblogs.com/

using System.Web.Mvc;

namespace Snowdream.Demo.LinkWithDescription
{
    /// <summary>
    /// 带描述的链接扩展类
    /// </summary>
    public static class LinkWithDescriptionExtensions
    {
        /// <summary>
        /// 带描述的链接扩展方法
        /// </summary>
        /// <param name="htmlHelper">要扩展的HtmlHelper类</param>
        /// <param name="title">标题</param>
        /// <param name="url">链接地址</param>
        /// <param name="description">描述</param>
        /// <returns>HTML代码</returns>
        public static MvcHtmlString LinkWithDescription(this HtmlHelper htmlHelper, string title, string url, string description)
        {
            // 生成与标题链接有关的HTML代码
            TagBuilder titleContainer = new TagBuilder("p");    // 标题链接容器p
            TagBuilder titleLink = new TagBuilder("a");    // 标题中的文字要有链接,所以包含在a标签内
            titleLink.MergeAttribute("href", url);    // 为a添加href属性并指定链接地址
            titleLink.SetInnerText(title);    // 标题文字
            titleContainer.InnerHtml = titleLink.ToString();    // 将a放到p中
            titleContainer.AddCssClass("LinkTitle");    // 为标题添加样式

            // 生成与链接描述有关的HTML代码
            TagBuilder descriptionContainer = new TagBuilder("p");    // 连接描述容器p
            descriptionContainer.InnerHtml = description;    // 描述文字
            descriptionContainer.AddCssClass("LinkDescription");    // 为描述添加样式

            // 将上述元素放入一个DIV中
            TagBuilder div = new TagBuilder("div");
            div.InnerHtml = string.Format("{0}{1}", titleContainer.ToString(), descriptionContainer.ToString());

            // 返回生成的HTML代码
            return MvcHtmlString.Create(div.ToString());
        }
    }
}